# =============== PREREQUISITES ======================

# Fast Nearest Neighbor
if (!require(package = "FNN")) {
  install.packages(pkgs = "FNN")
}
# For visualization
if (!require(package = "igraph")) {
  install.packages(pkgs = "igraph")
}
if (!require(package = "scales")) {
  install.packages(pkgs = "scales")
}
if (!require(package = "TDA")) {
  install.packages(pkgs = "TDA")
}


# ============= TWO CIRCLE EXAMPLE ===================
Circle1 = circleUnif(60)
Circle2 = circleUnif(60, r=2) +3
Circles=rbind(Circle1,Circle2)
par(mfrow=c(1,1))
plot(Circles, pch=16, xlab="", ylab="", main="Circles")

# Parameters
maxdimension=1 # components and loops
maxscale=5 # limit of the filtration

# Generate the persistence diagram
Diag <- ripsDiag(X=Circles, maxdimension, maxscale,
                 library="Dionysus", location=T, printProgress=FALSE)

# Display
par(mfrow=c(1,3), mai=c(0.8,0.8,0.3,0.1))
plot(Circles, pch=16, xlab="",ylab="", main="Sample")
plot(Diag$diagram, main="Rips Diagram")
legend(2.5,2, c("component", "loop"), col=c(1,2), pch=c(20,2),
       cex=0.9, pt.lwd=2)
plot(Diag$diagram, main="Rips Diagram", barcode = T)
# SWITCH TO PRESENTATION

# ============ PLASMID DATA ===================
plasmids <- as.matrix(read.csv("plasmids_distance_wo_names.csv", header=FALSE))

maxdimension <- 1 # components and loops
# What is my limit of the filtration?
mean(plasmids)
maxscale <- 600 # limit of the filtration

plasmids.rips <- ripsDiag(X=plasmids, maxdimension, maxscale, dist = "arbitrary",
              library="Dionysus", location=T, printProgress=T)

par(mfrow=c(1,1))
plot(plasmids.rips$diagram, main="831 Plasmids Rips Diagram")

# What points, aka plasmids, make the loops?
loops <- which(plasmids.rips[["diagram"]][, 1] == 1)
loops[1]
dim(plasmids.rips$cycleLocation[[loops[1]]])
plasmids.rips$cycleLocation[[loops[1]]]

# SWITCH TO PRESENTATION